@@ -1,5 +1,6 @@
 import asyncio
 from abc import ABC, abstractmethod, abstractproperty
+from types import TracebackType
 from typing import (
     Any, Awaitable, Callable, Coroutine, Dict, Iterable, NamedTuple, Optional,
     Set, Tuple, Type, Union,
@@ -64,6 +65,64 @@ class DeliveredMessage(NamedTuple):
     body: bytes
     channel: "AbstractChannel"
 
+    @property
+    def routing_key(self) -> Optional[str]:
+        if isinstance(
+            self.delivery, (
+                spec.Basic.Return,
+                spec.Basic.GetOk,
+                spec.Basic.Deliver,
+            ),
+        ):
+            return self.delivery.routing_key
+        return None
+
+    @property
+    def exchange(self) -> Optional[str]:
+        if isinstance(
+            self.delivery, (
+                spec.Basic.Return,
+                spec.Basic.GetOk,
+                spec.Basic.Deliver,
+            ),
+        ):
+            return self.delivery.exchange
+        return None
+
+    @property
+    def delivery_tag(self) -> Optional[int]:
+        if isinstance(
+            self.delivery, (
+                spec.Basic.GetOk,
+                spec.Basic.Deliver,
+            ),
+        ):
+            return self.delivery.delivery_tag
+        return None
+
+    @property
+    def redelivered(self) -> Optional[bool]:
+        if isinstance(
+            self.delivery, (
+                spec.Basic.GetOk,
+                spec.Basic.Deliver,
+            ),
+        ):
+            return self.delivery.redelivered
+        return None
+
+    @property
+    def consumer_tag(self) -> Optional[str]:
+        if isinstance(self.delivery, spec.Basic.Deliver):
+            return self.delivery.consumer_tag
+        return None
+
+    @property
+    def message_count(self) -> Optional[int]:
+        if isinstance(self.delivery, spec.Basic.GetOk):
+            return self.delivery.message_count
+        return None
+
 
 ChannelRType = Tuple[int, Channel.OpenOk]
 
@@ -491,6 +550,15 @@ class AbstractConnection(AbstractBase):
     async def __aenter__(self) -> "AbstractConnection":
         raise NotImplementedError
 
+    @abstractmethod
+    async def __aexit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_val: Optional[BaseException],
+        exc_tb: Optional[TracebackType],
+    ) -> Optional[bool]:
+        raise NotImplementedError
+
     @abstractmethod
     async def ready(self) -> None:
         raise NotImplementedError
